
;**************************************************************************
;*                         IR Power Switch                                *
;**************************************************************************
;*          1 duoled (GP0 & GP1) for signalization of activity            *
;**************************************************************************
;*          v 0.02 - 17.04.2011                                           *
;**************************************************************************
;*          Hardw.: PIC12F675 used                                        *
;*          OSC.......: Internal osc. used     POWER.....:  5V            *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
GPIO			     EQU     H'0005'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISIO                       EQU     H'0085'
CMCON                        EQU     H'0019'
ANSEL			     EQU     H'009F'

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'

;	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _INTRC_OSC_NOCLKOUT

_U001			     EQU     B'110100100'		;MCLR enabled
_U002			     EQU     B'110000100'		;MCLR disabled

	__CONFIG        _U001

;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	
TIMER3		EQU	H'22'		; "	"	"	
LEDR		EQU	H'23'
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts
		CLRF	ANSEL		;digital I/O

		;     GP  xx543210
		MOVLW	B'11101000'	;GP3 = input (it is acutally always an input)
					;GP5 = input
		MOVWF	TRISIO
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0


; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;efekt na uvod
		clrf	GPIO

effekt1		call	LED_red
		CALL	DELAY_ROUTINE4
		call	LED_off
		CALL	DELAY_ROUTINE4
		call	LED_red
		CALL	DELAY_ROUTINE4
		call	LED_off
		CALL	DELAY_ROUTINE4
		call	LED_red
		CALL	DELAY_ROUTINE4
		call	LED_off
		CALL	DELAY_ROUTINE4

;-------------------------------------------------------------------------
;main routine - power is OFF

main01		call	LED_red
		btfsc	GPIO,D'005'	;if GP5 = 0 --> IR detected
;nothing happens - no IR detected (input = 1)
		goto	main01

;-------------------------------------------------------------------------
;IR_found
		call	LED_off
		movlw	D'015'
		movwf	TIMER3

w001_x		MOVLW   D'100'
		MOVWF   TIMER2

w001_a		MOVLW   D'255'
		MOVWF   TIMER1

w001_b		btfsc	GPIO,D'005'	;there is still an IR signal
		goto	main01		;no IR anymore

w001_c		DECFSZ  TIMER1,F
                GOTO    w001_b
                DECFSZ  TIMER2,F
                GOTO    w001_a
		call	LED_swr
                DECFSZ  TIMER3,F
                GOTO    w001_x

;IR still there --> switch on		
		bsf	GPIO,D'002'	;switch the power on
		call	LED_green
;wait until IR is gone...
w003		btfss	GPIO,D'005'
		goto	w003

;------------------------------------------------------------------------
;main routine - power is ON
; tbc !!!!!!!!!!


main02		call	LED_green
		btfsc	GPIO,D'005'	;if GP5 = 0 --> IR detected
;nothing happens - no IR detected (input = 1)
		goto	main02


;IR_found
		call	LED_off
		movlw	D'015'
		movwf	TIMER3

w002_x		MOVLW   D'100'
		MOVWF   TIMER2

w002_a		MOVLW   D'255'
		MOVWF   TIMER1

w002_b		btfsc	GPIO,D'005'	;there is still an IR signal
		goto	main02		;no IR anymore

w002_c		DECFSZ  TIMER1,F
                GOTO    w002_b
                DECFSZ  TIMER2,F
                GOTO    w002_a
		call	LED_swg
                DECFSZ  TIMER3,F
                GOTO    w002_x

;IR still there --> switch off
		bcf	GPIO,D'002'	;switch the power off
		call	LED_red
;wait until IR is gone...
w004		btfss	GPIO,D'005'
		goto	w004

		goto	main01
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


LED_green	bsf	GPIO, D'000'
		bcf	GPIO, D'001'
		bsf	LEDR, D'001'
		return

LED_red		bsf	GPIO, D'001'
		bcf	GPIO, D'000'
		bsf	LEDR, D'000'
		return

LED_off		bcf	GPIO, D'000'
		bcf	GPIO, D'001'
		clrf	LEDR
		return

LED_swr		btfss	LEDR,D'000'
		goto	LED_red
		goto	LED_off
		
LED_swg		btfss	LEDR,D'001'
		goto	LED_green
		goto	LED_off


;		*********************************************
;		*               delay routine               *
;		*********************************************

;----------------------------------------------------------------------------
DELAY_ROUTINE3	MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP3_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1
		RETURN
;----------------------------------------------------------------------------
DELAY_ROUTINE4	call DELAY_ROUTINE3
		call DELAY_ROUTINE3
		call DELAY_ROUTINE3
		return

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


		END